pub struct AllowedRange {
pub min: i64,
pub max: i64,
}Fields
min: i64max: i64Implementations
Sourceimpl AllowedRange
impl AllowedRange
pub const fn new(min: i64, max: i64) -> Self
pub const fn no_check() -> Self
Sourcepub const fn from_bit_size(n_bits: usize, sign: Sign) -> Self
pub const fn from_bit_size(n_bits: usize, sign: Sign) -> Self
Note: for the 64-bit size, we actually do signed checks regardless of the sign argument
because the min and max are i64 type
Sourcepub const fn from_byte_size(n_bytes: usize, sign: Sign) -> Self
pub const fn from_byte_size(n_bytes: usize, sign: Sign) -> Self
Note: for the 8-byte size, we actually do signed checks regardless of the sign argument
because the min and max are i64 type