pub enum RelaxationKind {
NoOp,
ReplaceWithNop,
MovzX0Lsl16,
MovkX0,
MovzXnLsl16,
MovkXn,
AdrpToAdr,
AdrpX0,
LdrX0,
AddToAdr,
LdrToAdr,
}Variants
NoOp
Leave the instruction alone. Used when we only want to change the kind of relocation used.
ReplaceWithNop
Replace with nop
MovzX0Lsl16
Replace with movz x0 lsl #16
MovkX0
Replace with movk x0
MovzXnLsl16
Replace with movz xn lsl #16
MovkXn
Replace with movk xn
AdrpToAdr
Replace adrp with adr
AdrpX0
Replace with adrp x0 with adr
LdrX0
Replace with ldr x0
AddToAdr
Replace add with adr. We don’t apply this, but lld does, so this is used by linker-diff.
LdrToAdr
Implementations
Sourceimpl RelaxationKind
impl RelaxationKind
pub fn apply( self, section_bytes: &mut [u8], offset_in_section: &mut u64, _addend: &mut i64, )
pub fn next_modifier(&self) -> RelocationModifier