RelaxDelta

Struct RelaxDelta 

pub struct RelaxDelta {
    pub input_offset: u64,
    pub cumulative_deleted: u64,
    pub bytes_deleted: u32,
}
Records the number of bytes deleted at a specific offset within an input section.

Fields

input_offset: u64

Offset within the input section where the deletion occurs.

cumulative_deleted: u64

Cumulative bytes deleted up to and including this entry.

bytes_deleted: u32

Number of bytes deleted at this position.